@@ -15,57 +15,37 @@ def register_subparser(subparsers: Any) -> None:
     agg_parser.add_argument("-c", "--config", type=str,
                             default=".aicodec/config.json")
     agg_parser.add_argument(
-        "-d", "--directory",
+        "-d", "--directories",
+        nargs="+",
         type=str,
-        help="The root directory to scan."
+        help="One or more root directories to scan, overriding config."
     )
     agg_parser.add_argument(
-        "--include-dirs",
-        action="append",
-        nargs="+",
-        default=[],
-        help="Specific directories to include, overriding exclusions.",
-    )
-    agg_parser.add_argument(
-        "--include-exts",
-        action="append",
-        nargs="+",
-        default=[],
-        help="File extensions to include."
-    )
-    agg_parser.add_argument(
-        "--include-files",
+        "-i", "--include",
         action="extend",
         nargs="+",
         default=[],
-        help="Specific files or glob patterns to include.",
+        help="Specific files or glob patterns to include (gitignore-style).",
     )
     agg_parser.add_argument(
-        "--exclude-dirs",
+        "-e", "--exclude",
         action="extend",
         nargs="+",
         default=[],
-        help="Specific directories to exclude."
+        help="Specific files or glob patterns to exclude (gitignore-style)."
     )
     agg_parser.add_argument(
-        "--exclude-exts",
-        action="extend",
-        nargs="+",
-        default=[],
-        help="File extensions to exclude."
-    )
-    agg_parser.add_argument(
-        "--exclude-files",
-        action="extend",
-        nargs="+",
-        default=[],
-        help="Specific files or glob patterns to exclude."
-    )
-    agg_parser.add_argument(
-        "--full",
+        "-f", "--full",
         action="store_true",
         help="Perform a full aggregation, ignoring previous hashes.",
     )
+    agg_parser.add_argument(
+        "--plugin",
+        action="extend",
+        nargs="+",
+        default=[],
+        help="Define a plugin on the fly, e.g., '.ext=command {file}'. Overrides config plugins.",
+    )
     agg_parser.add_argument(
         "--count-tokens",
         action="store_true",
@@ -98,25 +78,46 @@ def run(args: Any) -> None:
         use_gitignore = use_gitignore_cfg
 
     project_root = Path.cwd().resolve()
-    scan_dir = project_root / \
-        Path(args.directory or file_cfg.get("directory", ".")).resolve()
-    exclude_dirs = args.exclude_dirs + file_cfg.get("exclude_dirs", [])
-    # Always exclude .aicodec and .git directories
-    exclude_dirs.extend([".aicodec", ".git"])
+
+    # Handle both "directories" (new) and "directory" (old) for backward compatibility
+    if "directories" in file_cfg:
+        config_dirs = file_cfg["directories"]
+    elif "directory" in file_cfg:
+        config_dirs = [file_cfg["directory"]]
+    else:
+        config_dirs = ["."]
+
+    scan_dirs_str = args.directories or config_dirs
+    scan_dirs = []
+    for d in scan_dirs_str:
+        path = Path(d)
+        if path.is_absolute():
+            scan_dirs.append(path.resolve())
+        else:
+            scan_dirs.append((project_root / path).resolve())
+
+    # Process and merge plugins
+    config_plugins = {}
+    for p_str in file_cfg.get("plugins", []):
+        if "=" in p_str:
+            ext, command = p_str.split("=", 1)
+            config_plugins[ext.strip()] = command.strip()
+
+    cli_plugins = {}
+    for p_str in args.plugin:
+        if "=" in p_str:
+            ext, command = p_str.split("=", 1)
+            cli_plugins[ext.strip()] = command.strip()
+    
+    # CLI plugins override config plugins
+    merged_plugins_map = {**config_plugins, **cli_plugins}
+    final_plugins = [{ext: cmd} for ext, cmd in merged_plugins_map.items()]
+
     config = AggregateConfig(
-        directory=scan_dir,
-        include_dirs=args.include_dirs or file_cfg.get("include_dirs", []),
-        include_ext=[
-            e if e.startswith(".") else "." + e
-            for e in args.include_exts or file_cfg.get("include_exts", [])
-        ],
-        include_files=args.include_files or file_cfg.get("include_files", []),
-        exclude_dirs=exclude_dirs,
-        exclude_exts=[
-            e if e.startswith(".") else "." + e
-            for e in args.exclude_exts or file_cfg.get("exclude_exts", [])
-        ],
-        exclude_files=args.exclude_files or file_cfg.get("exclude_files", []),
+        directories=scan_dirs,
+        include=args.include or file_cfg.get("include", []),
+        exclude=args.exclude + file_cfg.get("exclude", []),
+        plugins=final_plugins,
         use_gitignore=use_gitignore,
         project_root=project_root,
     )
